@@ -102,7 +102,8 @@ tfplot.default <- function(..., xlab=NULL, ylab=NULL,graphs.per.page=5,
   d <- obj[[1]]
   if (!is.tframed(d)) UseMethod("plot")
   else
-    {Ngraphs <- min(length(series), graphs.per.page)
+    {names <- series.names(d)
+     Ngraphs <- min(length(series), graphs.per.page)
      old.par <- par(mfcol = c(Ngraphs, 1))  # tfplot.TSdata also sets mar
      on.exit(par(old.par))
      for (i in series)
@@ -110,11 +111,11 @@ tfplot.default <- function(..., xlab=NULL, ylab=NULL,graphs.per.page=5,
         j <- 0
         for (d in obj)
     	  {if (!is.matrix(d)) d <- tframed(as.matrix(d), tframe(d))
-	   if(mode(i)=="character") i <- match(i, series.names(d))
+	   if(mode(i)=="character") i <- match(i, names)
 	   j <- j + 1
 	   z[,j] <- select.series(d, series=i)
 	  }
-	 tfOnePlot(tframed(z, tframe(d)),
+	 tfOnePlot(tframed(z, tframe(d), names=names[i]),
 	           xlab=xlab, ylab=ylab, start.=start., end.=end.)
 	}
     }
@@ -856,125 +857,3 @@ add.date <- function(date, periods, freq)
    c(date[1]+(date[2]+periods-1)%/%freq, 1+(date[2]+periods-1)%%freq)
   }
 
-
-###############################################
-
-#             tests   <<<<<<<<<<<<
-
-################################################
-
-
-
-
-tframe.function.tests <- function( verbose=T, synopsis=T)
-{# A short set of tests of the tframe class methods. 
-
-  all.ok <-  T
-  if (synopsis & !verbose) cat("All tframe tests ...")
-  if (verbose) cat("tframe test 1 ... ")
-  tspvector <- tframed(1:100, list(start=c(1981,3), frequency=4))
-  data <- matrix(rnorm(300),100,3)
-  tframe(data) <- tframe(tspvector)
-  ok <- is.tframed(data)
-  all.ok <- ok
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-
-  if (verbose) cat("tframe test 2 ... ")
-  ok <- test.equal(tframe(data), tframe(data))
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 3 ... ")
-  ok <- all(c(1981,3) == start(tspvector))
-  ok <- ok & all(c(1981,3) == start(data))
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 4 ... ")
-  ok <- all(end(data) == end(tspvector))
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 5 ... ")
-  ok <- periods(data) == periods(tspvector)
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 6 ... ")
-  ok <- frequency(data) == frequency(tspvector)
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 7 ... ")
-  z <- tframed(data, list(start=c(1961,2), frequency=12) )
-  ok <- is.tframed(z)
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 8 ... ")
-  z <- data[10:90,]
-  tframe(z) <- truncate.tframe(tframe(data), start=10, end=90)
-  ok <- is.tframed(z)
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 9 ... ")
-  z <- truncate(data, start=10, end=90)
-  ok <- is.tframed(z)
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 10... ")
-  data <- tframed(matrix(rnorm(300),100,3), list(start=c(1961,1), frequency=12))
-  z <- tfwindow(data, start=c(1963,2))
-  zz <-data
-  zz  <- tfwindow(zz, start=c(1963,2))
-  zzz <- tfwindow(data, start=c(1963,2))
-  tframe(zzz) <- tframe(z)
-  zzz <- tframed(zzz, tframe(zzz))
-  ok <- is.tframed(z) & is.tframed(zz) &  all(z==zz) & all(z==zzz)
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 11... ")
-  ok <- all( time(data) == time( tframed(data, tframe(data))))
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 12... ")
-  z <- tsmatrix(1:10, 11:20)
-  ok <-  all(start(z) ==1) & all( z== matrix(1:20, 10,2)) 
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 13... ")
-  data <- tframed(matrix(rnorm(300),100,3), list(start=c(1961,1), frequency=12))
-  z <- tfwindow(data, start=c(1963,2), end=c(1969,1))
-  ok <-      all(start(data)== earliest.start(data, z))
-  ok <- ok & all(    end(z) == earliest.end  (data, z))
-  ok <- ok & all(start(z)   == latest.start  (data, z))
-  ok <- ok & all( end(data) == latest.end   (data, z))
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if (verbose) cat("tframe test 14... ")
-  data <- tframed(matrix(rnorm(300),100,3), list(start=c(1961,1), frequency=12))
-  z <- tfwindow(data, start=c(1963,2), end=c(1969,1))
-  ok <- test.equal(data, splice(z, data))
-  ok <- ok & test.equal(tframe(data), tframe(splice(z, data)))
-  all.ok <- all.ok & ok 
-  if (verbose) {if (ok) cat("ok\n") else cat("failed!\n") }
-
-  if(!exists.graphics.device()) open.graphics.device()
-
-# dev.ask(T)
-# plot(data)
- tfplot(data)
-
-  if (synopsis) 
-    {if (verbose) cat("All tframe tests completed")
-     if (all.ok) cat(" OK\n") else cat(", some FAILED!\n") }
-  invisible(all.ok)
-}
-
